import { COMPLEX_TYPES, TOKENS, PRIMITIVE_TYPES } from "../constants";
export const stripSurrondingQuotes = (str) => {
    return str.replace(/^"(.*)"$/, "$1").replace(/^'(.*)'$/, "$1");
};
export const getWord = (doc, node, stripQuotes = true) => {
    const word = node ? doc.sliceString(node.from, node.to) : "";
    return stripQuotes ? stripSurrondingQuotes(word) : word;
};
export const isPrimitiveValueNode = (node) => {
    var _a;
    return (PRIMITIVE_TYPES.includes(node.name) ||
        (node.name === TOKENS.INVALID &&
            ((_a = node.prevSibling) === null || _a === void 0 ? void 0 : _a.name) === TOKENS.PROPERTY_NAME));
};
export const isValueNode = (node) => {
    var _a;
    return ([...PRIMITIVE_TYPES, ...COMPLEX_TYPES].includes(node.name) ||
        (node.name === TOKENS.INVALID &&
            ((_a = node.prevSibling) === null || _a === void 0 ? void 0 : _a.name) === TOKENS.PROPERTY_NAME));
};
export const isPropertyNameNode = (node) => {
    var _a;
    return (node.name === TOKENS.PROPERTY_NAME ||
        (node.name === TOKENS.INVALID &&
            ((_a = node.prevSibling) === null || _a === void 0 ? void 0 : _a.name) === TOKENS.PROPERTY) ||
        "{");
};
const getChildrenNodes = (node) => {
    const children = [];
    let child = node.firstChild;
    while (child) {
        if (child) {
            children.push(child);
        }
        child = child === null || child === void 0 ? void 0 : child.nextSibling;
    }
    return children;
};
export const getChildValueNode = (node) => {
    return getChildrenNodes(node).find((n) => isPrimitiveValueNode(n));
};
const getArrayNodeChildren = (node) => {
    return getChildrenNodes(node).filter((n) => PRIMITIVE_TYPES.includes(n.name) || COMPLEX_TYPES.includes(n.name));
};
export const findNodeIndexInArrayNode = (arrayNode, valueNode) => {
    return getArrayNodeChildren(arrayNode).findIndex((nd) => nd.from === valueNode.from && nd.to === valueNode.to);
};
